pub struct CreateTableEntryResponse {
pub table: Option<TableEntry>,
}Fields
table: Option<TableEntry>Trait Implementations
Sourceimpl Clone for CreateTableEntryResponse
impl Clone for CreateTableEntryResponse
Sourcefn clone(&self) -> CreateTableEntryResponse
fn clone(&self) -> CreateTableEntryResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateTableEntryResponse
impl Debug for CreateTableEntryResponse
Sourceimpl Default for CreateTableEntryResponse
impl Default for CreateTableEntryResponse
Sourceimpl Hash for CreateTableEntryResponse
impl Hash for CreateTableEntryResponse
Sourceimpl Message for CreateTableEntryResponse
impl Message for CreateTableEntryResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for CreateTableEntryResponse
impl Name for CreateTableEntryResponse
Sourceconst NAME: &'static str = "CreateTableEntryResponse"
const NAME: &'static str = "CreateTableEntryResponse"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "rerun.cloud.v1alpha1"
const PACKAGE: &'static str = "rerun.cloud.v1alpha1"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for CreateTableEntryResponse
impl PartialEq for CreateTableEntryResponse
Sourceimpl TryFrom<CreateTableEntryResponse> for CreateTableEntryResponse
impl TryFrom<CreateTableEntryResponse> for CreateTableEntryResponse
Sourcetype Error = TypeConversionError
type Error = TypeConversionError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<CreateTableEntryResponse> for CreateTableEntryResponse
impl TryFrom<CreateTableEntryResponse> for CreateTableEntryResponse
Sourcetype Error = TypeConversionError
type Error = TypeConversionError
The type returned in the event of a conversion error.
impl Eq for CreateTableEntryResponse
impl StructuralPartialEq for CreateTableEntryResponse