pub struct Query {
pub latest_at: Option<QueryLatestAt>,
pub range: Option<QueryRange>,
pub columns_always_include_everything: bool,
pub columns_always_include_byte_offsets: bool,
pub columns_always_include_entity_paths: bool,
pub columns_always_include_static_indexes: bool,
pub columns_always_include_global_indexes: bool,
pub columns_always_include_component_indexes: bool,
}Fields
latest_at: Option<QueryLatestAt>If specified, will perform a latest-at query with the given parameters.
You can combine this with a QueryRange in order to gather all the relevant chunks for
a full-fledged dataframe query (i.e. they get OR’d together).
range: Option<QueryRange>If specified, will perform a range query with the given parameters.
You can combine this with a QueryLatestAt in order to gather all the relevant chunks for
a full-fledged dataframe query (i.e. they get OR’d together).
columns_always_include_everything: boolIf true, columns will contain the entire schema.
columns_always_include_byte_offsets: boolIf true, columns always includes byte_offset and byte_size.
columns_always_include_entity_paths: boolIf true, columns always includes entity_path.
columns_always_include_static_indexes: boolIf true, columns always includes all static component-level indexes.
columns_always_include_global_indexes: boolIf true, columns always includes all temporal chunk-level indexes.
columns_always_include_component_indexes: boolIf true, columns always includes all component-level indexes.