#[repr(i32)]pub enum Encoding {
Unspecified = 0,
ArrowIpc = 1,
}Expand description
The encoding of the message payload.
Variants
Unspecified = 0
We don’t know what encoding the payload is in.
ArrowIpc = 1
The payload is encoded as Arrow-IPC.
Implementations
Sourceimpl Encoding
impl Encoding
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.